@@ -52,7 +52,6 @@ def SetAlarm():
         action_stop.label =str(txt.encode( "utf-8" ))
         action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
 
-
         data.AlarmID = alarm.add_event(event)
 
         event = alarm.get_event(data.AlarmID) #read out again to check if set correctly
@@ -150,7 +149,7 @@ def ProcessAlarm():
                         print "* But wake Up song is enabled, delay alarm for max", records.WakeUp_Song_Duration/60, "minutes"
                         records.AlarmTime_seconds=min(records.AlarmTime_seconds+records.WakeUp_Song_Duration, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
                         records.AlarmTime_tuple=Seconds2Tuple(records.AlarmTime_seconds)
-                        records.WakeUp_SongIsActive=True
+                        data.WakeUp_SongIsActive=True
                         records.WakeUp_Song_Start_tuple=Seconds2Tuple(now)
                         print "* Delay alarm until:", records.AlarmTime_tuple
 
@@ -163,12 +162,18 @@ def ProcessAlarm():
                 if(now >= records.AlarmTime_seconds): #alarm is due
                     records.Trigger=data.Trigger #update Trigger level on alarm occurence
                     data.AlarmIsActive=True
+                    data.Lucid_Dream_SongIsActive=True #make sure lucid dream option will not run after wake up option got active
+#                    PauseSong() #stop playing song, in case it was playing
+                    CloseMediaPlayer() #close media player
 
     elif(now>=records.AlarmTimeWindowEnd_seconds): #End of alarm time window, set alarm off anyway
         if(records.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
             print "************ ALARM ALARM (End of Alarm Time Window)"
             records.Trigger=data.Trigger #update Trigger level on alarm occurence
             data.AlarmIsActive=True
+            data.Lucid_Dream_SongIsActive=True #make sure lucid dream option will not run after wake up option got active
+#            PauseSong() #stop playing song, in case it was playing
+            CloseMediaPlayer() #close media player
 
 
 
@@ -184,4 +189,4 @@ def ProcessLucid_Dream(): #Lucid dream option
             data.Lucid_Dream_SongIsActive=True
             records.Lucid_Dream_Song_Start_tuple=time.localtime() #now
             print "Play Lucid dream song"
-            PlaySong(records.Lucid_Dream_Song_Volume, data.Lucid_Dream_Song)
\ No newline at end of file
+            PlaySong(records.Lucid_Dream_Song_Volume, data.Lucid_Dream_Song)
