@@ -238,10 +238,7 @@ def LoadConfig():
     else: #config file up to date
         pass
 
-
-
     print "Configuration successful loaded from "+data.ConfigFile
-
     return config
 
 
@@ -256,27 +253,32 @@ def LoadConfig():
 ## Write the configuration into the config file
 ###########################################################################
 def WriteConfig():
-        global config
-        config.set('main', 'Trigger', str(data.Trigger))
-        config.set('main', 'ConfigFileVersion', str(data.configFileVersion))
-
-        f=data.configFolder+data.ConfigFile
-        if(data.debug==True): print "Save configuration ("+f+")"
-        if (not os.path.exists(data.configFolder)):
-            print "Create configuration folder: ",  data.configFolder
-            os.mkdir(data.configFolder)
-        try:
-            data.configfile = open(f, 'w')
-            config.write(data.configfile)
-            data.configfile.close()
-            print "Configuration saved"
-        except:
-            print "Failed to write configuration file!"
+    global config
+    config.set('main', 'Trigger', str(data.Trigger))
+    config.set('main', 'ConfigFileVersion', str(data.configFileVersion))
 
+    f=data.configFolder+data.ConfigFile
+    if(data.debug==True): print "Save configuration ("+f+")"
+    if (not os.path.exists(data.configFolder)):
+        print "Create configuration folder: ",  data.configFolder
+        os.mkdir(data.configFolder)
+    try:
+        data.configfile = open(f, 'w')
+        config.write(data.configfile)
+        data.configfile.close()
+        print "Configuration saved"
+    except:
+        print "Failed to write configuration file!"
 
 
 
 
+def PrintConfig():
+    print "###################### CONFIG DATA #######################"
+    a=config.items("main")
+    for i in range(0, len(a)): #print data
+        print a[i]
+    print "##########################################################"
 
 
 ###########################################################################
@@ -447,6 +449,16 @@ def PlaySong(volume, filename):
     b.close()
 
 
+
+
+def PauseSong():
+    print strftime("%x %X"), "Pause song (if active)"
+    cmd="dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause"
+    b = os.popen(cmd)
+    b.close()
+
+
+
 def GetSongLength(filename):
     print "get song length for file:", filename
     output = os.popen("ffmpeg -i \""+str(filename)+"\" 2>&1 | grep Duration").read() # run ffmpeg and make the output look like a file I can read
@@ -457,6 +469,14 @@ def GetSongLength(filename):
 
 
 
+def CloseMediaPlayer():
+    print strftime("%x %X"), "killall mediaplayer"
+    cmd="killall mediaplayer"
+    b = os.popen(cmd)
+    b.close()
+
+
+
 
 
 ############################################################################
@@ -471,4 +491,4 @@ def GetSongLength(filename):
 #    t2=1000*(now-data.passed_time2)
 #    print "### ",  str(int(t)), "ms, (",  str(int(t2)), "ms delta): ", text
 #
-#    data.passed_time2 = time.time()
\ No newline at end of file
+#    data.passed_time2 = time.time()
